package Yote::Test::TestNoDeepCloner;

use strict;
use warnings;

use vars qw($VERSION);
$VERSION = '0.01';

use parent 'Yote::AppRoot';

1;

__END__

=head1 AUTHOR

Eric Wolf

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2011 Eric Wolf

This module is free software; it can be used under the same terms as perl
itself.

=cut
